VersionInfo

Struct VersionInfo 

pub struct VersionInfo<'a> { /* private fields */ }
Version Information.

Implementations

Source

impl<'a> VersionInfo<'a>

pub fn try_from(bytes: &'a [u8]) -> Result<VersionInfo<'a>>

pub fn fixed(self) -> Option<&'a VS_FIXEDFILEINFO>

Gets the fixed file information if available.

Queries \.

pub fn translation(self) -> &'a [Language]

Gets the available languages.

Queries \VarFileInfo\Translation.

pub fn value(self, lang: Language, key: &str) -> Option<String>

Gets a string value by name.

Queries \StringFileInfo\{lang}\{key}

pub fn strings<F: FnMut(&str, &str)>(self, lang: Language, f: F)

Iterates over all the strings’ keys and values of a given language.

Queries \StringFileInfo\{lang}\*

pub fn file_info(self) -> FileInfo<'a>

Parse the version info into HashMaps.

pub fn source_code(self) -> String

Renders the version info back into its source code form.

pub fn visit(self, visit: &mut dyn Visit<'a>)

Parse the version information.

Because of the super convoluted format, the visitor pattern is used. Implement the Visit trait to get the desired information.

To keep the API simple all errors are ignored, any invalid or corrupted data is skipped.